.. _homogenization-nonlinear_homogenization:

homogenization/nonlinear_homogenization.py
==========================================

**Description**

missing description!



:download:`source code </../sfepy/examples/homogenization/nonlinear_homogenization.py>`

.. literalinclude:: /../sfepy/examples/homogenization/nonlinear_homogenization.py

